"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.consoleReplay = consoleReplay;
exports.default = buildConsoleReplay;
var RenderUtils_1 = __importDefault(require("./RenderUtils"));
var scriptSanitizedVal_1 = __importDefault(require("./scriptSanitizedVal"));
function consoleReplay(customConsoleHistory, numberOfMessagesToSkip) {
    if (customConsoleHistory === void 0) { customConsoleHistory = undefined; }
    if (numberOfMessagesToSkip === void 0) { numberOfMessagesToSkip = 0; }
    // console.history is a global polyfill used in server rendering.
    var consoleHistory = customConsoleHistory !== null && customConsoleHistory !== void 0 ? customConsoleHistory : console.history;
    if (!(Array.isArray(consoleHistory))) {
        return '';
    }
    var lines = consoleHistory.slice(numberOfMessagesToSkip).map(function (msg) {
        var stringifiedList = msg.arguments.map(function (arg) {
            var val;
            try {
                if (typeof arg === 'string') {
                    val = arg;
                }
                else if (arg instanceof String) {
                    val = String(arg);
                }
                else {
                    val = JSON.stringify(arg);
                }
                if (val === undefined) {
                    val = 'undefined';
                }
            }
            catch (e) {
                val = "".concat(e.message, ": ").concat(arg);
            }
            return (0, scriptSanitizedVal_1.default)(val);
        });
        return "console.".concat(msg.level, ".apply(console, ").concat(JSON.stringify(stringifiedList), ");");
    });
    return lines.join('\n');
}
function buildConsoleReplay(customConsoleHistory, numberOfMessagesToSkip) {
    if (customConsoleHistory === void 0) { customConsoleHistory = undefined; }
    if (numberOfMessagesToSkip === void 0) { numberOfMessagesToSkip = 0; }
    return RenderUtils_1.default.wrapInScriptTags('consoleReplayLog', consoleReplay(customConsoleHistory, numberOfMessagesToSkip));
}
